PyTerrier Alpha
=======================================================

`pyterrier-alpha <https://github.com/seanmacavaney/pyterrier-alpha>`__ is an alpha channel of
features for PyTerrier,

Features in this package are under development and intend to be merged with the main package or
split into a separate package when stable.

.. rubric:: Getting Started

.. code-block:: console
    :caption: Install ``pyterrier-alpha`` with ``pip``

    $ pip install pyterrier-alpha

Import ``pyterrier_alpha`` alongside ``pyterrier``:

.. code-block:: python
    :caption: Importing ``pyterrier_alpha``

    import pyterrier as pt
    import pyterrier_alpha as pta

.. rubric:: Alpha Features

.. toctree::
    :maxdepth: 1

    artifact
    dataframe_builder
    rbo
    inspect
    io
    transform
    utils
    validate
